
# If configured to do so by an external source
# (eg /ukshells/scripts/slackwareupdate) then
# restart Apache
# Apache requires a restart in order to reload libphp4.so
#
if [ -f /var/log/ukshells-configure/apache.restart ]; then
   /etc/rc.d/rc.httpd stop
   /etc/rc.d/rc.httpd start
fi

