
# If configured to do so by an external source
# (eg /ukshells/scripts/slackwareupdate) then
# restart the snmpd daemon
if [ -f /var/log/ukshells-configure/snmpd.restart ]; then
   /etc/rc.d/rc.snmpd stop
   /etc/rc.d/rc.snmpd start
fi

